function remove_homo(filename1,filename2,filename3,cutoff)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Chua Gek Huey
% Library: HuaySequenceLib
% Function: remove_homo
% Usage: remove_homo(filename1,filename2,filename3,cutoff)
% Description: Filter off sequences of %homology>cutoff
%              based on %identity found in Clustal_W file
%           filename1=input file in fasta format
%           filename2=output file in fasta format
%           filename3=Clustal_W file
%   Note: if you have the %identity stored in a matrix instead
%          of a Clustal_W file, use remove_homo_d
% Last Edited: 04 Aug 2005
% See Also: remove_homo_d, plot_cumulative, fasta, ConvertAA3to1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nargin<4
    disp('Usage: remove_homo(input file, output file, Clustal_W file, cutoff percentage)');
    return;
end


[seq,seq_len,seq_name] = fasta(filename1);

fcw=fopen(filename3,'rt');
flag=0;
count=0;
while ~feof(fcw)
   tline=fgetl(fcw);
   if strcmp(tline,'Aligning...')
       tline=fgetl(fcw);
       flag=1;
   elseif findstr(tline,'Guide tree')
       break;
   end
   if (flag==1)
       count=count+1;
       pos=findstr('(',tline);
       pos1=pos(1)+1;
       tline1=tline(pos1:length(tline));
       seq1=sscanf(tline1,'%d');
   
       pos=findstr(':',tline);
       pos2=pos(1)+1;
       tline2=tline(pos2:length(tline));
       seq2=sscanf(tline2,'%d');
   
       pos3=pos(2)+1;
       tline3=tline(pos3:length(tline));
       score(seq1,seq2)=sscanf(tline3,'%f');
       score(seq2,seq1)=score(seq1,seq2);
   end
    
end
fclose(fcw);


indicator(1:size(score,1))=1;
for i=1:size(score)
   for j=i+1:size(score)
       if (indicator(j)==1 & indicator(i)==1)
           if (score(i,j)>cutoff)
               indicator(j)=0;
           end
       end
   end
end


fid=fopen(filename2,'wt');
length(indicator);
for i=1:length(indicator)
   if (indicator(i)==1)
       fprintf(fid,'>%s\n%s\n',char(seq_name(i)),seq(i,1:seq_len(i)));
   end
end

fclose(fid);


