function remove_homo_d(filename1,filename2,score,cutoff)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Chua Gek Huey
% Library: HuaySequenceLib
% Function: remove_homo_d
% Usage: remove_homo_d(filename1,filename2,score,cutoff)
% Description: Filter out sequences with homology > cutoff
%           filename1=input file in fasta format
%           filename2=output file in fasta format
%           score contains the %similarity or %identity
%           if score> cutoff, sequence will not be selected
% Last Edited: 04 Aug 2005
% See Also: remove_homo, plot_cumulative, fasta, ConvertAA3to1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nargin<4
    disp('Usage: remove_homo(input file, output file, dist matrix, cutoff percentage)');
    return;
end

[seq,seq_len,seq_name] = fasta(filename1);

indicator(1:size(score,1))=1;
for i=1:size(score)
   for j=i+1:size(score)
       if (indicator(j)==1 & indicator(i)==1)
           if (score(i,j)>cutoff)
               indicator(j)=0;
           end
       end
   end
end


fid=fopen(filename2,'wt');
length(indicator);
for i=1:length(indicator)
   if (indicator(i)==1)
       fprintf(fid,'>%s\n%s\n',char(seq_name(i)),seq(i,1:seq_len(i)));
   end
end

fclose(fid);


